
* paper estimates were obtained using Stata/MP 13 for Windows
set more off
cd "path"
use "JDemEcon.dta", clear

* keep only countries with no discoveries in the previous 15 years
gen temp=year if oildiscovery!=0 & oildiscovery!=. & L.oildiscovery==0 & year<1951
by numcode, sort: egen priordisc=max(temp)
drop if priordisc!=.
drop temp priordisc

by numcode, sort: egen treat=max(oildiscovery)
gen dem2=dem^2

****************************************************************************
* TB A2 USE MATCHED SAMPLE
* matching at the beginning of the period
* if beginning of period is 1951********
psmatch2 treat gdp_pc ecgrowth dem dem2 area nationalization mountain at_war if year==1951, radius ///
	caliper(0.05) common 
pstest ecgrowth gdp_pc dem dem2 area nationalization mountain at_war, both

by numcode, sort: egen weight=max(_weight)
sort numcode year
set more off
local discovery= "oildiscovery L.oildiscovery L2.oildiscovery L3.oildiscovery L4.oildiscovery L5.oildiscovery L6.oildiscovery L7.oildiscovery L8.oildiscovery L9.oildiscovery L10.oildiscovery "
local controls= "L.totalpop L.gdp_pc L.ecgrowth L.dem at_war "

foreach depvar in sex_ratio2 imr {	
	xi: areg `depvar' `discovery' `controls'  i.year [aw=weight] , absorb(numcode) cluster(numcode)
	outreg2 using match.xls, label  bdec(3) asterisk(coef) keep(`discovery' )   
}

* if beginning of period is 1960  *******
drop _pscore _treated _support _weight weight
psmatch2 treat gdp_pc ecgrowth dem dem2 at_war area nationalization mountain if year==1960, radius ///
	caliper(0.05) common 
pstest ecgrowth gdp_pc dem dem2 area at_war nationalization mountain, both

by numcode, sort: egen weight=max(_weight)
sort numcode year
set more off
local discovery= "oildiscovery L.oildiscovery L2.oildiscovery L3.oildiscovery L4.oildiscovery L5.oildiscovery L6.oildiscovery L7.oildiscovery L8.oildiscovery L9.oildiscovery L10.oildiscovery "
local controls= "L.totalpop L.gdp_pc L.ecgrowth L.dem at_war "
	xi: areg teenbirths `discovery' `controls'  i.year [aw=weight] , absorb(numcode) cluster(numcode)
	outreg2 using match2.xls, label  bdec(3) asterisk(coef) keep(`discovery' )   

* if beginning of period is 1970 ********
drop _pscore _treated _support _weight weight
psmatch2 treat gdp_pc ecgrowth dem dem2 area nationalization mountain at_war if year==1970, radius ///
	caliper(0.05) common 
pstest ecgrowth gdp_pc dem dem2 area nationalization mountain at_war, both

by numcode, sort: egen weight=max(_weight)
sort numcode year
set more off
local discovery= "oildiscovery L.oildiscovery L2.oildiscovery L3.oildiscovery L4.oildiscovery L5.oildiscovery L6.oildiscovery L7.oildiscovery L8.oildiscovery L9.oildiscovery L10.oildiscovery "
local controls= "L.totalpop L.gdp_pc L.ecgrowth L.dem at_war "
foreach depvar in foverm_primarysch foverm_scndsch foverm_tertiarysch  {	
	xi: areg `depvar' `discovery' `controls'  i.year [aw=weight] , absorb(numcode) cluster(numcode)
	outreg2 using match3.xls, label  bdec(3) asterisk(coef) keep(`discovery' )   
}
**************************************************************************************
************ TB A3 EXCLUDE AUTOCRACIES; Polity>-5
set more off
local discovery= "oildiscovery L.oildiscovery L2.oildiscovery L3.oildiscovery L4.oildiscovery L5.oildiscovery L6.oildiscovery L7.oildiscovery L8.oildiscovery L9.oildiscovery L10.oildiscovery "
local controls= "L.totalpop L.gdp_pc L.ecgrowth L.dem at_war"
foreach depvar in teenbirths sex_ratio2 imr foverm_tertiarysch {	
	xi: areg `depvar' `discovery' `controls'  i.year  if L.polity>=-5, absorb(numcode) cluster(numcode)
	outreg2 using Dem.xls, label  bdec(3) asterisk(coef) keep(`discovery' )   
}

local discovery= "oildiscovery L.oildiscovery L2.oildiscovery L3.oildiscovery L4.oildiscovery L5.oildiscovery L6.oildiscovery L7.oildiscovery L8.oildiscovery L9.oildiscovery L10.oildiscovery "
local controls= "L.totalpop L.gdp_pc L.ecgrowth L.dem at_war"
	xi: areg sex_ratio2 `discovery' `controls'  i.year  if L.polity>=-5 & largeregion!=2, absorb(numcode) cluster(numcode)
	outreg2 using Dem.xls, label  bdec(3) asterisk(coef) keep(`discovery' )   

***************************************************************************************
***********Tb A4 EXCLUDE WHEN HIGH PROPORTION MUSLIM; >10% Muslim
 set more off
local discovery= "oildiscovery L.oildiscovery L2.oildiscovery L3.oildiscovery L4.oildiscovery L5.oildiscovery L6.oildiscovery L7.oildiscovery L8.oildiscovery L9.oildiscovery L10.oildiscovery "
local controls= "L.totalpop L.gdp_pc L.ecgrowth L.dem at_war"
foreach depvar in teenbirths sex_ratio2 imr foverm_tertiarysch {	
	xi: areg `depvar' `discovery' `controls'  i.year  if  muslim<0.1, absorb(numcode) cluster(numcode)
	outreg2 using NoMuslim.xls, label  bdec(3) asterisk(coef) keep(`discovery' )   
}

local discovery= "oildiscovery L.oildiscovery L2.oildiscovery L3.oildiscovery L4.oildiscovery L5.oildiscovery L6.oildiscovery L7.oildiscovery L8.oildiscovery L9.oildiscovery L10.oildiscovery "
local controls= "L.totalpop L.gdp_pc L.ecgrowth L.dem at_war"
	xi: areg sex_ratio2 `discovery' `controls'  i.year  if largeregion!=2 & muslim<0.1, absorb(numcode) cluster(numcode)
	outreg2 using NoMuslim.xls, label  bdec(3) asterisk(coef) keep(`discovery' )   

***************************************************************************************
*********** Tb A5 LABOR FORCE PARTICIPATION
set more off
local discovery= "oildiscovery L.oildiscovery L2.oildiscovery L3.oildiscovery L4.oildiscovery L5.oildiscovery L6.oildiscovery L7.oildiscovery L8.oildiscovery L9.oildiscovery L10.oildiscovery "
local controls= "L.totalpop L.gdp_pc L.ecgrowth L.dem at_war"
	xi: areg lpr `discovery' `controls'  i.year, absorb(numcode) cluster(numcode)
	outreg2 using labor_force.xls, label  bdec(3) asterisk(coef) keep(`discovery') ctitle(disc)  

gen disc_area=oildiscovery*1000/area
local discovery= "disc_area L.disc_area L2.disc_area L3.disc_area L4.disc_area L5.disc_area L6.disc_area L7.disc_area L8.disc_area L9.disc_area L10.disc_area"
local controls= "L.totalpop L.gdp_pc L.ecgrowth L.dem at_war"
	xi: areg lpr `discovery' `controls'  i.year, absorb(numcode) cluster(numcode)
	outreg2 using labor_force.xls, label  bdec(3) asterisk(coef) keep(`discovery') ctitle(disc/area) 

gen amt_area=amt_oildisc*100/area
local discovery= "amt_area L.amt_area L2.amt_area L3.amt_area L4.amt_area L5.amt_area L6.amt_area L7.amt_area L8.amt_area L9.amt_area L10.amt_area"
local controls= "L.totalpop L.gdp_pc L.ecgrowth L.dem at_war"
	xi: areg lpr `discovery' `controls'  i.year, absorb(numcode) cluster(numcode)
	outreg2 using labor_force.xls, label  bdec(3) asterisk(coef) keep(`discovery') ctitle(amt per area) 

gen all_oilgas_disc=oildiscovery+gasdiscovery+off_oilgasdiscovery
local discovery= "all_oilgas_disc L.all_oilgas_disc L2.all_oilgas_disc L3.all_oilgas_disc L4.all_oilgas_disc L5.all_oilgas_disc L6.all_oilgas_disc L7.all_oilgas_disc L8.all_oilgas_disc L9.all_oilgas_disc L10.all_oilgas_disc "
local controls= "L.totalpop L.gdp_pc L.ecgrowth L.dem at_war"
	xi: areg lpr `discovery' `controls'  i.year, absorb(numcode) cluster(numcode)
	outreg2 using labor_force.xls, label  bdec(3) asterisk(coef) keep(`discovery') ctitle(oilgas) 
	
***************************************************************************************
***********Tabla A6 oil+gas
set more off
local discovery= "all_oilgas_disc L.all_oilgas_disc L2.all_oilgas_disc L3.all_oilgas_disc L4.all_oilgas_disc L5.all_oilgas_disc L6.all_oilgas_disc L7.all_oilgas_disc L8.all_oilgas_disc L9.all_oilgas_disc L10.all_oilgas_disc "
local controls= "L.totalpop L.gdp_pc L.ecgrowth L.dem at_war"
foreach depvar in teenbirths sex_ratio2 imr foverm_tertiarysch {	
	xi: areg `depvar' `discovery' `controls'  i.year , absorb(numcode) cluster(numcode)
	outreg2 using oilgas.xls, label  bdec(3) asterisk(coef) keep(`discovery' )   
}

local discovery= "all_oilgas_disc L.all_oilgas_disc L2.all_oilgas_disc L3.all_oilgas_disc L4.all_oilgas_disc L5.all_oilgas_disc L6.all_oilgas_disc L7.all_oilgas_disc L8.all_oilgas_disc L9.all_oilgas_disc L10.all_oilgas_disc "
local controls= "L.totalpop L.gdp_pc L.ecgrowth L.dem at_war"
	xi: areg sex_ratio2 `discovery' `controls'  i.year if largeregion!=2, absorb(numcode) cluster(numcode)
	outreg2 using oilgas.xls, label  bdec(3) asterisk(coef) keep(`discovery' )   

***************************************************************************************
********* Table A8 predict discovery
gen if_disc=oildiscovery
replace if_disc=1 if oildiscovery>0 & oildiscovery!=.

set more off
reg if_disc L.sex_ratio0 L.sex_ratio1 L.sex_ratio2 L.sex_ratio3 L.sex_ratio4 L.sex_ratio5 ///
	L.sex_ratio10 L.sex_ratio15 L.teenbirths L.cbr L.tfr   L.LExMale L.LExFemale  ///
	L.foverm_primarysch L.foverm_scndsch L.foverm_tertiarysch ///
	L.lpr ///
	L.totalpop L.gdp_pc L.ecgrowth L.dem at_war i.year , robust cluster(numcode) 
	
	outreg2 using predict_discovery.xls, label  bdec(3) asterisk(coef) keep(L.sex_ratio0 L.sex_ratio1 L.sex_ratio2 L.sex_ratio3 L.sex_ratio4 L.sex_ratio5 ///
	L.sex_ratio10 L.sex_ratio15 L.teenbirths L.cbr L.tfr   L.LExMale L.LExFemale  ///
	L.foverm_primarysch L.foverm_scndsch L.foverm_tertiarysch ///
	L.lpr ///
	L.totalpop L.gdp_pc L.ecgrowth L.dem at_war) replace  

***************************************************************************************
********* Table A9 detrend GDP and pop
generate trend=year-1949
foreach var in totalpop gdp_pc ecgrowth dem {
	gen L`var'=L.`var'
	}

foreach var in Ltotalpop Lgdp_pc Lecgrowth {
reg `var' trend	
predict `var'_detrend, resid
}

set more off
local discovery= "oildiscovery L.oildiscovery L2.oildiscovery L3.oildiscovery L4.oildiscovery L5.oildiscovery L6.oildiscovery L7.oildiscovery L8.oildiscovery L9.oildiscovery L10.oildiscovery "
local controls= "Ltotalpop_detrend Lgdp_pc_detrend Lecgrowth_detrend L.dem at_war"
foreach depvar in teenbirths sex_ratio2 imr foverm_tertiarysch {	
	xi: areg `depvar' `discovery' `controls'  i.year , absorb(numcode) cluster(numcode)
	outreg2 using detrend.xls, label  bdec(3) asterisk(coef) keep(`discovery' )   
}

local discovery= "oildiscovery L.oildiscovery L2.oildiscovery L3.oildiscovery L4.oildiscovery L5.oildiscovery L6.oildiscovery L7.oildiscovery L8.oildiscovery L9.oildiscovery L10.oildiscovery "
local controls= "Ltotalpop_detrend Lgdp_pc_detrend Lecgrowth_detrend L.dem at_war"
	xi: areg sex_ratio2 `discovery' `controls'  i.year if largeregion!=2, absorb(numcode) cluster(numcode)
	outreg2 using detrend.xls, label  bdec(3) asterisk(coef) keep(`discovery' ) ctitle(M/F2 no_africa)  

***************************************************************************************
********* Table A10 Newey West
*  newey west std err correction for std err
tabulate year, generate (yr)	
tabulate numcode, generate (nm)	

set more off
local discovery= "oildiscovery L.oildiscovery L2.oildiscovery L3.oildiscovery L4.oildiscovery L5.oildiscovery L6.oildiscovery L7.oildiscovery L8.oildiscovery L9.oildiscovery L10.oildiscovery "
local controls= "L.totalpop L.gdp_pc L.ecgrowth L.dem at_war"
foreach depvar in teenbirths sex_ratio2 imr foverm_tertiarysch {
	qui newey `depvar' `discovery' `controls'  yr* nm*, lag(10) force
	outreg2 using firstdisc_NW.xls, label  bdec(3) asterisk(coef) keep(`discovery')   
}

local discovery= "oildiscovery L.oildiscovery L2.oildiscovery L3.oildiscovery L4.oildiscovery L5.oildiscovery L6.oildiscovery L7.oildiscovery L8.oildiscovery L9.oildiscovery L10.oildiscovery "
local controls= "L.totalpop L.gdp_pc L.ecgrowth L.dem at_war"
	qui newey sex_ratio2 `discovery' `controls'  yr* nm* if largeregion!=2, lag(10) force
	outreg2 using firstdisc_NW.xls, label  bdec(3) asterisk(coef) keep(`discovery') ctitle(MF2no_africa)  

***************************************************************************************
********* Table A11 panel corrected standard error accounting for cross-sectional dependence standard errors (Driscoll and Kraay 1998)
tsset numcode year
gen Loildiscovery=L.oildiscovery
forvalues i=2(1)10 {
	gen L`i'oildiscovery=L`i'.oildiscovery
}
set more off
local discovery= "oildiscovery Loildiscovery L2oildiscovery L3oildiscovery L4oildiscovery L5oildiscovery L6oildiscovery L7oildiscovery L8oildiscovery L9oildiscovery L10oildiscovery "
local controls= "Ltotalpop Lgdp_pc Lecgrowth Ldem at_war yr*"

foreach depvar in teenbirths sex_ratio2 imr foverm_tertiarysch {	
	 xtscc `depvar' `discovery' `controls' , fe
	outreg2 using DKstderr.xls, label  bdec(3) asterisk(coef) keep(`discovery' )   
}
tsset numcode year
set more off
local discovery= "oildiscovery Loildiscovery L2oildiscovery L3oildiscovery L4oildiscovery L5oildiscovery L6oildiscovery L7oildiscovery L8oildiscovery L9oildiscovery L10oildiscovery "
local controls= "Ltotalpop Lgdp_pc Lecgrowth Ldem at_war yr*"
	 xtscc sex_ratio2 `discovery' `controls'  if largeregion!=2, fe
	outreg2 using DKstderr.xls, label  bdec(3) asterisk(coef) keep(`discovery' )   

***************************************************************************************
********* Table A12 no controls
set more off
local discovery= "oildiscovery L.oildiscovery L2.oildiscovery L3.oildiscovery L4.oildiscovery L5.oildiscovery L6.oildiscovery L7.oildiscovery L8.oildiscovery L9.oildiscovery L10.oildiscovery "
local controls= "L.totalpop L.gdp_pc L.ecgrowth L.dem at_war"

foreach depvar in teenbirths sex_ratio2 imr foverm_tertiarysch {	
	xi: areg `depvar' `discovery' `controls'  i.year , absorb(numcode) cluster(numcode)
	xi: areg `depvar' `discovery'   i.year if e(sample), absorb(numcode) cluster(numcode)
	outreg2 using Noctrl.xls, label  bdec(3) asterisk(coef) keep(`discovery' )   
}

local discovery= "oildiscovery L.oildiscovery L2.oildiscovery L3.oildiscovery L4.oildiscovery L5.oildiscovery L6.oildiscovery L7.oildiscovery L8.oildiscovery L9.oildiscovery L10.oildiscovery "
local controls= "L.totalpop L.gdp_pc L.ecgrowth L.dem at_war"
	xi: areg sex_ratio2 `discovery' `controls'  i.year if largeregion!=2, absorb(numcode) cluster(numcode)
	xi: areg sex_ratio2 `discovery'   i.year if largeregion!=2 & e(sample), absorb(numcode) cluster(numcode)
	outreg2 using Noctrl.xls, label  bdec(3) asterisk(coef) keep(`discovery' )   

********* Table A13 pre-trends
set more off
gen temp=year if oildiscovery==1 & L.oildiscovery==0
by numcode, sort: egen discyr=max(temp)
drop temp
gen pretrend=-1 if year==discyr-1
forvalues x = 1(1)10 {
	replace pretrend=-`x' if year==discyr-`x'
}
replace pretrend=0 if pretrend==.

local discovery= "oildiscovery L.oildiscovery L2.oildiscovery L3.oildiscovery L4.oildiscovery L5.oildiscovery L6.oildiscovery L7.oildiscovery L8.oildiscovery L9.oildiscovery L10.oildiscovery "
local controls= "L.totalpop L.gdp_pc L.ecgrowth L.dem at_war"
foreach depvar in teenbirths sex_ratio2 imr foverm_tertiarysch {	
	xi: areg `depvar' `discovery' `controls'  i.year pretrend , absorb(numcode) cluster(numcode)
	outreg2 using pretrends.xls, label  bdec(3) asterisk(coef) keep(`discovery')   
}

local discovery= "oildiscovery L.oildiscovery L2.oildiscovery L3.oildiscovery L4.oildiscovery L5.oildiscovery L6.oildiscovery L7.oildiscovery L8.oildiscovery L9.oildiscovery L10.oildiscovery "
local controls= "L.totalpop L.gdp_pc L.ecgrowth L.dem at_war"
	xi: areg sex_ratio2 `discovery' `controls'  i.year pretrend if largeregion!=2, absorb(numcode) cluster(numcode)
	outreg2 using pretrends.xls, label  bdec(3) asterisk(coef) keep(`discovery')   

********* Table A14 Pool Mean Group
* pooled mean-group
* keep countries that discovered oil
set more off
gen temp=1 if oildiscovery==1 & L.oildiscovery==0 
by numcode, sort: egen found=max(temp)
keep if found==1
drop temp found
* drop unused observations - speeds up estimation
keep if oildiscovery!=. &  totalpop!=. & gdp_pc!=. & ecgrowth!=. & dem!=. & at_war!=.

tsset numcode year
	set more off
foreach depvar in teenbirths sex_ratio2 imr LExMale LExFemale  {	
xtpmg  D.`depvar' D.oildiscovery D.Ltotalpop D.Lgdp_pc D.Lecgrowth D.Ldem D.at_war , lr( L.`depvar' oildiscovery  Ltotalpop Lgdp_pc Lecgrowth Ldem at_war) pmg ec(ec`depvar')
	outreg2 using pgm.xls, label  bdec(3) asterisk(coef) keep(D.oildiscovery oildiscovery)   
}	
	
xtpmg  D.sex_ratio2 D.oildiscovery D.Ltotalpop D.Lgdp_pc D.Lecgrowth D.Ldem D.at_war if largeregion!=2, lr( L.sex_ratio2 oildiscovery  Ltotalpop Lgdp_pc Lecgrowth Ldem at_war) pmg ec(ecMF2NoAfrica)
	outreg2 using pgm.xls, label  bdec(3) asterisk(coef) keep(D.oildiscovery oildiscovery)   

***************************************************************************************
***********Table A7 all countries
use "JDemEcon.dta", clear
local discovery= "oildiscovery L.oildiscovery L2.oildiscovery L3.oildiscovery L4.oildiscovery L5.oildiscovery L6.oildiscovery L7.oildiscovery L8.oildiscovery L9.oildiscovery L10.oildiscovery "
local controls= "L.totalpop L.gdp_pc L.ecgrowth L.dem at_war"
foreach depvar in teenbirths sex_ratio2 imr foverm_tertiarysch {	
	xi: areg `depvar' `discovery' `controls'  i.year  , absorb(numcode) cluster(numcode)
	outreg2 using allctr.xls, label  bdec(3) asterisk(coef) keep(`discovery' )   
}

local discovery= "oildiscovery L.oildiscovery L2.oildiscovery L3.oildiscovery L4.oildiscovery L5.oildiscovery L6.oildiscovery L7.oildiscovery L8.oildiscovery L9.oildiscovery L10.oildiscovery "
local controls= "L.totalpop L.gdp_pc L.ecgrowth L.dem at_war"
	xi: areg sex_ratio2 `discovery' `controls'  i.year  if largeregion!=2, absorb(numcode) cluster(numcode)
	outreg2 using allctr.xls, label  bdec(3) asterisk(coef) keep(`discovery' )   

********** Table A15 more micro data
* Colombia
use "Colombia.dta", clear

* 104 "oriental" 105 "bogota"
gen treatment=1 if (region==104 | region==105) & year>=1992
replace treatment=0 if treatment==.

set more off
foreach depvar in breastfeed vaccine diarrhea treat_diarrhea treat_fever {
xi: reg `depvar' treatment age  urban i.region i.year [pw=smpl_wgt] if k_male==1 & k_calc_age<=2, robust 
	outreg2 using COinv.xls, label  bdec(3) asterisk(coef) keep(treatment)  ctitle(M`depvar') nocons
xi: reg `depvar' treatment age  urban i.region i.year [pw=smpl_wgt] if k_male==0 & k_calc_age<=2, robust 
	outreg2 using COinv.xls, label  bdec(3) asterisk(coef) keep(treatment)  ctitle(F`depvar') nocons
}

* Indonesia
use "Indonesia.dta", clear
*15	south kalimantan; 25 east kalimantan
set more off 
gen treatment=1 if (region==25 | region==15 ) & year>=1996
replace treatment=0 if treatment==.

set more off
foreach depvar in breastfeed vaccine diarrhea treat_diarrhea treat_fever {
xi: reg `depvar' treatment age  urban i.region i.year [pw=smpl_wgt] if k_male==1 & k_calc_age<=2, robust cluster(region)
	outreg2 using IDinvest.xls, label  bdec(3) asterisk(coef) keep(treatment)  ctitle(M`depvar') nocons
xi: reg `depvar' treatment age  urban i.region i.year [pw=smpl_wgt] if k_male==0 & k_calc_age<=2, robust cluster(region)
	outreg2 using IDinvest.xls, label  bdec(3) asterisk(coef) keep(treatment)  ctitle(F`depvar') nocons
}

